@@ -1,5 +1,4 @@
 import abc
-from opengsq.socket_async import SocketAsync
 
 
 class ProtocolBase(abc.ABC):
@@ -9,7 +8,6 @@ class ProtocolBase(abc.ABC):
         pass
 
     def __init__(self, address: str, query_port: int, timeout: float = 5.0):
-        self._sock = None
         self._address = address
         self._query_port = query_port
         self._timeout = timeout
